package com.chinaitop.depot.intelligent.ventilation.model;

import java.util.Date;

public class TVentilation {
    private String id;

    private String orgId;

    private String vCfCode;

    private String operationId;

    private String vDevName;

    private String vDeviceCode;

    private String vPattern;

    private Date vStartTime;

    private Date vEndTime;

    private Integer vDistinguishState;

    private Integer vState;

    private String vUpdatePerson;

    private String dataSource;

    private Date vUpdateTime;

    /**
     * 32位唯一编码 设备作业记录表
     * @return id 32位唯一编码 设备作业记录表
     */
    public String getId() {
        return id;
    }

    /**
     * 32位唯一编码 设备作业记录表
     * @param id 32位唯一编码 设备作业记录表
     */
    public void setId(String id) {
        this.id = id == null ? null : id.trim();
    }

    /**
     * 库房id
     * @return org_id 库房id
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 库房id
     * @param orgId 库房id
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 仓房编码
     * @return v_cf_code 仓房编码
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房编码
     * @param vCfCode 仓房编码
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 计划id 记录是通风还是熏蒸 或其他作业
     * @return operation_id 计划id 记录是通风还是熏蒸 或其他作业
     */
    public String getOperationId() {
        return operationId;
    }

    /**
     * 计划id 记录是通风还是熏蒸 或其他作业
     * @param operationId 计划id 记录是通风还是熏蒸 或其他作业
     */
    public void setOperationId(String operationId) {
        this.operationId = operationId == null ? null : operationId.trim();
    }

    /**
     * 设备名称
     * @return v_dev_name 设备名称
     */
    public String getvDevName() {
        return vDevName;
    }

    /**
     * 设备名称
     * @param vDevName 设备名称
     */
    public void setvDevName(String vDevName) {
        this.vDevName = vDevName == null ? null : vDevName.trim();
    }

    /**
     * 设备类型
     * @return v_device_code 设备类型
     */
    public String getvDeviceCode() {
        return vDeviceCode;
    }

    /**
     * 设备类型
     * @param vDeviceCode 设备类型
     */
    public void setvDeviceCode(String vDeviceCode) {
        this.vDeviceCode = vDeviceCode == null ? null : vDeviceCode.trim();
    }

    /**
     * 通风模式
     * @return v_pattern 通风模式
     */
    public String getvPattern() {
        return vPattern;
    }

    /**
     * 通风模式
     * @param vPattern 通风模式
     */
    public void setvPattern(String vPattern) {
        this.vPattern = vPattern == null ? null : vPattern.trim();
    }

    /**
     * 通风开始时间
     * @return v_start_time 通风开始时间
     */
    public Date getvStartTime() {
        return vStartTime;
    }

    /**
     * 通风开始时间
     * @param vStartTime 通风开始时间
     */
    public void setvStartTime(Date vStartTime) {
        this.vStartTime = vStartTime;
    }

    /**
     * 通风结束时间
     * @return v_end_time 通风结束时间
     */
    public Date getvEndTime() {
        return vEndTime;
    }

    /**
     * 通风结束时间
     * @param vEndTime 通风结束时间
     */
    public void setvEndTime(Date vEndTime) {
        this.vEndTime = vEndTime;
    }

    /**
     * 记录是通风状态还是熏蒸状态 0通风，1熏蒸
     * @return v_distinguish_state 记录是通风状态还是熏蒸状态 0通风，1熏蒸
     */
    public Integer getvDistinguishState() {
        return vDistinguishState;
    }

    /**
     * 记录是通风状态还是熏蒸状态 0通风，1熏蒸
     * @param vDistinguishState 记录是通风状态还是熏蒸状态 0通风，1熏蒸
     */
    public void setvDistinguishState(Integer vDistinguishState) {
        this.vDistinguishState = vDistinguishState;
    }

    /**
     * 0:关闭,1:打开,2:反转,3:停止
     * @return v_state 0:关闭,1:打开,2:反转,3:停止
     */
    public Integer getvState() {
        return vState;
    }

    /**
     * 0:关闭,1:打开,2:反转,3:停止
     * @param vState 0:关闭,1:打开,2:反转,3:停止
     */
    public void setvState(Integer vState) {
        this.vState = vState;
    }

    /**
     * 创建人
     * @return v_update_person 创建人
     */
    public String getvUpdatePerson() {
        return vUpdatePerson;
    }

    /**
     * 创建人
     * @param vUpdatePerson 创建人
     */
    public void setvUpdatePerson(String vUpdatePerson) {
        this.vUpdatePerson = vUpdatePerson == null ? null : vUpdatePerson.trim();
    }

    /**
     * 数据来源
     * @return data_source 数据来源
     */
    public String getDataSource() {
        return dataSource;
    }

    /**
     * 数据来源
     * @param dataSource 数据来源
     */
    public void setDataSource(String dataSource) {
        this.dataSource = dataSource == null ? null : dataSource.trim();
    }

    /**
     * 创建时间
     * @return v_update_time 创建时间
     */
    public Date getvUpdateTime() {
        return vUpdateTime;
    }

    /**
     * 创建时间
     * @param vUpdateTime 创建时间
     */
    public void setvUpdateTime(Date vUpdateTime) {
        this.vUpdateTime = vUpdateTime;
    }
}